This project is archived and is in readonly mode.
Changeset [0ab40b039bf7b7882a31ab187916bc2dc5a8ae7c] by Yehuda Katz
Revision 0ab40b039bf7b7882a31ab187916bc2dc5a8ae7c,
committed by Yehuda Katz
· August 9th, 2009 @ 08:12 AM
Went from 25% slower partials (vs. 2.3) to 10% faster. More to come. http://github.com/rails/rails/co...
3 changed files
-
M
actionpack/examples/minimal.rb -
M
actionpack/lib/action_view/render/partials.rb -
M
actionpack/lib/action_view/template/template.rb